/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     DATEQ2 */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int dateq2_(integer *iy, integer *itd)
{
    static integer id, im;
    extern /* Subroutine */ int date32_(integer *, integer *, integer *, 
	    integer *), dateq3_(integer *, integer *, integer *);

/*     IY    : YEAR                                              ( /O) */
/*     ITD   : TOTAL DAY                                         ( /O) */
    dateq3_(iy, &im, &id);
    date32_(iy, &im, &id, itd);
    return 0;
} /* dateq2_ */

